@@ -1,3 +1,7 @@
+/* Copyright Vladimir Prus 2002. Distributed under the Boost */
+/* Software License, Version 1.0. (See accompanying */
+/* file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt) */
+
 #include "jam.h"
 #include "lists.h"
 #include "newstr.h"
@@ -10,7 +14,11 @@
 #include <direct.h>
 #define PATH_MAX _MAX_PATH
 #else
+#include <limits.h>
 #include <unistd.h>
+#if defined(__COMO__)
+     #include <linux/limits.h>
+#endif
 #endif
 
 
